@@ -3,14 +3,14 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: SQLite setup/teardown for tests
 
-our $VERSION = '0.0106';
+our $VERSION = '0.0200';
 
 use Moo;
 use strictures 2;
 
 use DBI;
 use File::Copy;
-use File::Temp qw/ tempfile /;
+use File::Temp ();
 
 
 has database => (
@@ -27,6 +27,12 @@ has schema => (
 );
 
 
+has db_attrs => (
+    is      => 'ro',
+    default => sub { return { RaiseError => 1, AutoCommit => 1 } },
+);
+
+
 has dsn => (
     is       => 'lazy',
     init_arg => undef,
@@ -45,7 +51,7 @@ has dbh => (
 
 sub _build_dbh {
     my ($self) = @_;
-    return DBI->connect( $self->dsn, '', '' );
+    return DBI->connect( $self->dsn, '', '', $self->db_attrs );
 }
 
 has _database => (
@@ -66,7 +72,7 @@ sub _build__database {
         open my $schema, '<', $self->schema
             or die "Can't read " . $self->schema . ": $!";
 
-        my $dbh = DBI->connect( 'dbi:SQLite:dbname=' . $filename, '', '' )
+        my $dbh = DBI->connect( 'dbi:SQLite:dbname=' . $filename, '', '', { RaiseError => 1, AutoCommit => 0 } )
             or die "Failed to open DB $filename: " . $DBI::errstr;
 
         my $sql = '';
@@ -83,6 +89,8 @@ sub _build__database {
             }
         }
 
+        $dbh->commit;
+
         $dbh->disconnect;
     }
 
@@ -112,20 +120,23 @@ Test::SQLite - SQLite setup/teardown for tests
 
 =head1 VERSION
 
-version 0.0106
+version 0.0200
 
 =head1 SYNOPSIS
 
   use DBI;
   use Test::SQLite;
 
-  my $sqlite = Test::SQLite->new(database => '/some/where/production.db');
+  my $sqlite = Test::SQLite->new(
+    database => '/some/where/production.db',
+    db_attrs => { RaiseError => 1, AutoCommit => 0 },
+  );
 
-  my $dbh = DBI->connect($sqlite->dsn, '', '');
+  my $dbh = $sqlite->dbh;
 
   $sqlite = Test::SQLite->new(schema => '/some/where/schema.sql');
 
-  $dbh = $sqlite->dbh;
+  $dbh = DBI->connect($sqlite->dsn, '', '', $sqlite->db_attrs);
 
 =head1 DESCRIPTION
 
@@ -153,13 +164,17 @@ The SQL schema to create a test database.
 
 Boolean indicating that a schema file was provided to the constructor.
 
+=head2 db_attrs
+
+DBI connection attributes.  Default: { RaiseError => 1, AutoCommit => 1 }
+
 =head2 dsn
 
 The database connection string.
 
 =head2 dbh
 
-A connected database handle.
+A connected database handle based on the B<dsn> and B<db_attrs>.
 
 =head1 METHODS
 
